;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

(autoload 'custom-add-loads "cus-load")

(custom-add-loads 'cperl '("cperl-mode"))
(custom-add-loads 'cperl-indentation-details '("cperl-mode"))
(custom-add-loads 'cperl-speed '("cperl-mode"))
(custom-add-loads 'cperl-affected-by-hairy '("cperl-mode"))
(custom-add-loads 'cperl-autoinsert-details '("cperl-mode"))
(custom-add-loads 'cperl-faces '("cperl-mode"))
(custom-add-loads 'languages '("cperl-mode"))
(custom-add-loads 'cperl-help-system '("cperl-mode"))

;;; custom-load.el ends here
